@@ -1,4 +1,11 @@
 package MooseX::Role::Pluggable::Plugin;
+{
+  $MooseX::Role::Pluggable::Plugin::VERSION = '0.03';
+}
+BEGIN {
+  $MooseX::Role::Pluggable::Plugin::AUTHORITY = 'cpan:GENEHACK';
+}
+# ABSTRACT: Role for plugins to consume
 use Moose::Role;
 use Moose::Util::TypeConstraints;
 
@@ -24,9 +31,15 @@ no Moose::Role;
 
 __END__
 
+=pod
+
 =head1 NAME
 
-MooseX::Role::Pluggable::Plugin - add plugins to your Moose classes
+MooseX::Role::Pluggable::Plugin - Role for plugins to consume
+
+=head1 VERSION
+
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -53,6 +66,10 @@ Classes that want to utilize plugins should consume the
 'MooseX::Role::Pluggable' role; see the documentation for that module for more
 information.
 
+=head1 NAME
+
+MooseX::Role::Pluggable::Plugin - add plugins to your Moose classes
+
 =head1 AUTHOR
 
 John SJ Anderson, C<genehack@genehack.org>
@@ -68,4 +85,15 @@ Copyright 2010, John SJ Anderson
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 AUTHOR
+
+John SJ Anderson <genehack@genehack.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2013 by John SJ Anderson.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
